@@ -363,7 +363,7 @@ Value ListFindFunction::Execute(int arity,Value *arg)
         {
             CList *outlist = new CList(results.size());
 
-            for(int i=0; i < results.size(); i++)
+            for(unsigned int i=0; i < results.size(); i++)
             {
                 (*outlist)[i] = results[i];
             }
